@@ -197,7 +197,7 @@ delete_adls_filesystem.adls_endpoint <- function(endpoint, name, confirm=TRUE, .
 
 #' Operations on an Azure Data Lake Storage Gen2 filesystem
 #'
-#' Upload, download, or delete a file; list files in a directory; create or delete directories.
+#' Upload, download, or delete a file; list files in a directory; create or delete directories; check file existence.
 #'
 #' @param filesystem An ADLSgen2 filesystem object.
 #' @param dir,file A string naming a directory or file respectively.
@@ -220,11 +220,18 @@ delete_adls_filesystem.adls_endpoint <- function(endpoint, name, confirm=TRUE, .
 #'
 #' `upload_adls_file` and `download_adls_file` can display a progress bar to track the file transfer. You can control whether to display this with `options(azure_storage_progress_bar=TRUE|FALSE)`; the default is TRUE.
 #'
+#' @section AzCopy:
+#' `upload_azure_file` and `download_azure_file` have the ability to use the AzCopy commandline utility to transfer files, instead of native R code. This can be useful if you want to take advantage of AzCopy's logging and recovery features; it may also be faster in the case of transferring a very large number of small files. To enable this, set the `use_azcopy` argument to TRUE.
+#'
+#' Note that AzCopy only supports SAS and AAD (OAuth) token as authentication methods. AzCopy also expects a single filename or wildcard spec as its source/destination argument, not a vector of filenames or a connection.
+#'
 #' @return
 #' For `list_adls_files`, if `info="name"`, a vector of file/directory names. If `info="all"`, a data frame giving the file size and whether each object is a file or directory.
 #'
 #' For `download_adls_file`, if `dest=NULL`, the contents of the downloaded file as a raw vector.
 #'
+#' For `adls_file_exists`, either TRUE or FALSE.
+#'
 #' @seealso
 #' [adls_filesystem], [az_storage], [storage_download], [call_azcopy]
 #'
@@ -347,7 +354,7 @@ multiupload_adls_file <- function(filesystem, src, dest, recursive=FALSE, blocks
                                    max_concurrent_transfers=10)
 {
     if(use_azcopy)
-        return(azcopy_upload(filesystem, src, dest, blocksize=blocksize, lease=lease))
+        return(azcopy_upload(filesystem, src, dest, blocksize=blocksize, lease=lease, recursive=recursive))
 
     multiupload_internal(filesystem, src, dest, recursive=recursive, blocksize=blocksize, lease=lease,
                          max_concurrent_transfers=max_concurrent_transfers)
@@ -371,7 +378,7 @@ multidownload_adls_file <- function(filesystem, src, dest, recursive=FALSE, bloc
                                     max_concurrent_transfers=10)
 {
     if(use_azcopy)
-        return(azcopy_upload(filesystem, src, dest, overwrite=overwrite))
+        return(azcopy_download(filesystem, src, dest, overwrite=overwrite, recursive=recursive))
 
     multidownload_internal(filesystem, src, dest, recursive=recursive, blocksize=blocksize, overwrite=overwrite,
                            max_concurrent_transfers=max_concurrent_transfers)
@@ -418,3 +425,14 @@ delete_adls_dir <- function(filesystem, dir, recursive=FALSE, confirm=TRUE)
     invisible(do_container_op(filesystem, dir, options=opts, http_verb="DELETE"))
 }
 
+#' @rdname adls
+#' @export
+adls_file_exists <- function(filesystem, file)
+{
+    res <- do_container_op(filesystem, file, headers = list(), http_verb = "HEAD", http_status_handler = "pass")
+    if (httr::status_code(res) == 404L)
+        return(FALSE)
+
+    httr::stop_for_status(res, storage_error_message(res))
+    return(TRUE)
+}
