@@ -215,7 +215,7 @@ delete_blob_container.blob_endpoint <- function(endpoint, name, confirm=TRUE, le
 
 #' Operations on a blob container or blob
 #'
-#' Upload, download, or delete a blob; list blobs in a container.
+#' Upload, download, or delete a blob; list blobs in a container; check blob availability.
 #'
 #' @param container A blob container object.
 #' @param blob A string naming a blob.
@@ -241,8 +241,13 @@ delete_blob_container.blob_endpoint <- function(endpoint, name, confirm=TRUE, le
 #'
 #' `upload_blob` and `download_blob` can display a progress bar to track the file transfer. You can control whether to display this with `options(azure_storage_progress_bar=TRUE|FALSE)`; the default is TRUE.
 #'
+#' @section AzCopy:
+#' `upload_blob` and `download_blob` have the ability to use the AzCopy commandline utility to transfer files, instead of native R code. This can be useful if you want to take advantage of AzCopy's logging and recovery features; it may also be faster in the case of transferring a very large number of small files. To enable this, set the `use_azcopy` argument to TRUE.
+#'
+#' Note that AzCopy only supports SAS and AAD (OAuth) token as authentication methods. AzCopy also expects a single filename or wildcard spec as its source/destination argument, not a vector of filenames or a connection.
+#'
 #' @return
-#' For `list_blobs`, details on the blobs in the container. For `download_blob`, if `dest=NULL`, the contents of the downloaded blob as a raw vector.
+#' For `list_blobs`, details on the blobs in the container. For `download_blob`, if `dest=NULL`, the contents of the downloaded blob as a raw vector. For `blob_exists` a flag whether the blob exists.
 #'
 #' @seealso
 #' [blob_container], [az_storage], [storage_download], [call_azcopy]
@@ -380,7 +385,7 @@ multiupload_blob <- function(container, src, dest, recursive=FALSE, type="BlockB
                              max_concurrent_transfers=10)
 {
     if(use_azcopy)
-        return(azcopy_upload(container, src, dest, type=type, blocksize=blocksize, lease=lease))
+        return(azcopy_upload(container, src, dest, type=type, blocksize=blocksize, lease=lease, recursive=recursive))
 
     multiupload_internal(container, src, dest, recursive=recursive, type=type, blocksize=blocksize, lease=lease,
                          max_concurrent_transfers=max_concurrent_transfers)
@@ -403,7 +408,7 @@ multidownload_blob <- function(container, src, dest, recursive=FALSE, blocksize=
                                max_concurrent_transfers=10)
 {
     if(use_azcopy)
-        return(azcopy_download(container, src, dest, overwrite=overwrite, lease=lease))
+        return(azcopy_download(container, src, dest, overwrite=overwrite, lease=lease, recursive=recursive))
 
     multidownload_internal(container, src, dest, recursive=recursive, blocksize=blocksize, overwrite=overwrite,
                            lease=lease, max_concurrent_transfers=max_concurrent_transfers)
@@ -419,4 +424,14 @@ delete_blob <- function(container, blob, confirm=TRUE)
     invisible(do_container_op(container, blob, http_verb="DELETE"))
 }
 
+#' @rdname blob
+#' @export
+blob_exists <- function(container, blob)
+{
+    res <- do_container_op(container, blob, headers = list(), http_verb = "HEAD", http_status_handler = "pass")
+    if (httr::status_code(res) == 404L)
+        return(FALSE)
 
+    httr::stop_for_status(res, storage_error_message(res))
+    return(TRUE)
+}
