@@ -134,6 +134,10 @@ test_that("Blob client interface works",
     iris3 <- as.data.frame(jsonlite::fromJSON(con))
     expect_identical(iris, iris3)
 
+    # check blob
+    expect_false(blob_exists(cont, "nonexistent"))
+    expect_true(blob_exists(cont, "iris.json"))
+
     # ways of deleting a container
     delete_blob_container(cont, confirm=FALSE)
     delete_blob_container(bl, "newcontainer2", confirm=FALSE)
